@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Position of notes in a scale
 
-our $VERSION = '0.0101';
+our $VERSION = '0.0102';
 
 use Carp;
 use Moo;
@@ -46,9 +46,9 @@ sub get_offset {
     }
 
     my $posn = first { $scale[$_] eq $note->format('isobase') } 0 .. $#scale;
-#warn(__PACKAGE__,' L',__LINE__,". MARK: $args{note_name}=$posn\n");
+#warn(__PACKAGE__,' L',__LINE__,". MARK: $args{note_name}=$posn\n") if $posn;
 
-    $args{offset} += $posn;
+    $args{offset} += $posn if $posn;
 
     my $octave = $note->octave;
     my $factor = int( $args{offset} / @scale );
@@ -80,7 +80,7 @@ Music::ScaleNote - Position of notes in a scale
 
 =head1 VERSION
 
-version 0.0101
+version 0.0102
 
 =head1 SYNOPSIS
 
